@@ -53,7 +53,6 @@
 #define HAVE_MALLOC_H 1
 #define HAVE_PWD_H 1
 #define HAVE_SANITIZER_ASAN_INTERFACE_H 1
-#define HAVE_SANITIZER_MSAN_INTERFACE_H 1
 #define HAVE_STDALIGN_H 1
 #define HAVE_STDIO_H 1
 #define HAVE_SYS_EVENTFD_H 1
@@ -77,6 +76,7 @@
 #define HAVE_UCONTEXT_H 1
 #define HAVE_UTIME_H 1
 #define HAVE_SYS_EPOLL_H 1
+#define HAVE_STDCKDINT_H 1
 #define HAVE_STDATOMIC_H 1
 #define HAVE_X86INTRIN_H 1
 #if defined(__x86_64__)
@@ -178,7 +178,8 @@
 #define HAVE_FUNC_WEAK 1
 #define RUBY_CXX_DEPRECATED(msg) __attribute__((__deprecated__(msg)))
 #define HAVE_NULLPTR 1
-#define FUNC_CDECL(x) __attribute__ ((__cdecl__)) x
+#define FUNC_UNOPTIMIZED(x) __attribute__ ((__optimize__("O0"))) x
+#define FUNC_MINIMIZED(x) __attribute__ ((__optimize__("-Os","-fomit-frame-pointer"))) x
 #define HAVE_ATTRIBUTE_FUNCTION_ALIAS 1
 #define RUBY_ALIAS_FUNCTION_TYPE(type, prot, name, args) type prot __attribute__((alias(#name)));
 #define RUBY_ALIAS_FUNCTION_VOID(prot, name, args) RUBY_ALIAS_FUNCTION_TYPE(void, prot, name, args)
@@ -333,7 +334,6 @@
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_GETUID 1
 #define HAVE_GMTIME_R 1
-#define HAVE_GRANTPT 1
 #define HAVE_INITGROUPS 1
 #define HAVE_IOCTL 1
 #define HAVE_KILL 1
@@ -429,15 +429,20 @@
 #define HAVE_BUILTIN___BUILTIN_CLZLL 1
 #define HAVE_BUILTIN___BUILTIN_CTZ 1
 #define HAVE_BUILTIN___BUILTIN_CTZLL 1
-#define HAVE_BUILTIN___BUILTIN_ADD_OVERFLOW 1
-#define HAVE_BUILTIN___BUILTIN_SUB_OVERFLOW 1
-#define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW 1
 #define HAVE_BUILTIN___BUILTIN_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
 #define HAVE_BUILTIN___BUILTIN_TRAP 1
 #define HAVE_BUILTIN___BUILTIN_EXPECT 1
+#define HAVE_BUILTIN___BUILTIN_ADD_OVERFLOW 1
+#define HAVE_BUILTIN___BUILTIN_ADD_OVERFLOW_P 1
+#define USE___BUILTIN_ADD_OVERFLOW_LONG_LONG 1
+#define HAVE_BUILTIN___BUILTIN_SUB_OVERFLOW 1
+#define HAVE_BUILTIN___BUILTIN_SUB_OVERFLOW_P 1
+#define USE___BUILTIN_SUB_OVERFLOW_LONG_LONG 1
+#define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW 1
+#define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW_P 1
 #define USE___BUILTIN_MUL_OVERFLOW_LONG_LONG 1
 #define HAVE_GNU_QSORT_R 1
 #define ATAN2_INF_C99 1
@@ -473,7 +478,7 @@
 #define HAVE_GETCONTEXT 1
 #define HAVE_SETCONTEXT 1
 #define HAVE_SYS_USER_H 1
-#define HAVE_CONST_PAGE_SIZE 1
+#define HAVE_CONST_PAGE_SIZE 0
 #define IOCTL_REQ_TYPE unsigned long
 #define NUM2IOCTLREQ(num) NUM2ULONG(num)
 #define USE_ELF 1
@@ -482,12 +487,15 @@
 #define HAVE_BACKTRACE 1
 #define DLEXT_MAXLEN 3
 #define DLEXT ".so"
+#define SOEXT ".so"
 #define LIBDIR_BASENAME "lib64"
 #define HAVE__SETJMP 1
 #define RUBY_SETJMP(env) setjmp((env))
 #define RUBY_LONGJMP(env,val) longjmp((env),val)
 #define RUBY_JMP_BUF jmp_buf
+#define USE_MODULAR_GC 0
 #define USE_YJIT 0
 #define USE_RJIT 1
 #define RUBY_PLATFORM "x86_64-linux"
+#define RB_DEFAULT_PARSER RB_DEFAULT_PARSER_PRISM
 #endif /* INCLUDE_RUBY_CONFIG_H */
